==> agrosyst-cli-1.4.9-sources.jar: fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java <==
package fr.inra.agrosyst.services.pz0import.action.seedingActionSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: SeedingActionSpeciesImportDto.java 4837 2015-03-17 15:48:52Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.9/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.action.SeedingActionSpeciesAbstract;

/**
 * Created by davidcosse on 12/02/15.
 */
public class SeedingActionSpeciesImportDto extends SeedingActionSpeciesAbstract {

    protected String id;

    protected Double quantityWithNull;

    protected String seedPlantUnitName;

    protected String seedingActionId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Double getQuantityWithNull() {
        return quantityWithNull;
    }

    public void setQuantityWithNull(Double quantityWithNull) {
        this.quantityWithNull = quantityWithNull;
    }

    public String getSeedPlantUnitName() {
        return seedPlantUnitName;
    }

    public void setSeedPlantUnitName(String seedPlantUnitName) {
        this.seedPlantUnitName = seedPlantUnitName;
    }

    public String getSeedingActionId() {
        return seedingActionId;
    }

    public void setSeedingActionId(String seedingActionId) {
        this.seedingActionId = seedingActionId;
    }

}

==> agrosyst-cli-1.5.1-sources.jar: fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java <==
package fr.inra.agrosyst.services.pz0import.action.seedingActionSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: SeedingActionSpeciesImportDto.java 5054 2015-08-06 13:04:27Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.5.1/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.action.SeedingAction;
import fr.inra.agrosyst.api.entities.action.SeedingActionSpeciesAbstract;

/**
 * Created by davidcosse on 12/02/15.
 */
public class SeedingActionSpeciesImportDto extends SeedingActionSpeciesAbstract {

    protected String id;

    protected Double quantityWithNull;

    protected String seedPlantUnitName;

    protected String seedingActionId;

    protected SeedingAction seedingAction;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Double getQuantityWithNull() {
        return quantityWithNull;
    }

    public void setQuantityWithNull(Double quantityWithNull) {
        this.quantityWithNull = quantityWithNull;
    }

    public String getSeedPlantUnitName() {
        return seedPlantUnitName;
    }

    public void setSeedPlantUnitName(String seedPlantUnitName) {
        this.seedPlantUnitName = seedPlantUnitName;
    }

    public String getSeedingActionId() {
        return seedingActionId;
    }

    public void setSeedingActionId(String seedingActionId) {
        this.seedingActionId = seedingActionId;
    }

    public SeedingAction getSeedingAction() {
        return seedingAction;
    }

    public void setSeedingAction(SeedingAction seedingAction) {
        this.seedingAction = seedingAction;
    }
}
